Infallible

Enum Infallible 

pub enum Infallible {}
A marker type used for infallible memory, where memory access is valid and won’t trigger page faults.

The most prominent example of infallible memory is kernel virtual memory (at least for the part where Rust code and data reside).

VmReader and VmWriter types use this marker type to indicate the property of the underlying memory.